@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/bin/sh
 set -e
 
 # Parse command line arguments
@@ -39,8 +39,11 @@ done
 
 # Resolve Qt root path argument if provided (expand ~ and convert to absolute path)
 if [ -n "$QT_ROOT_ARG" ]; then
-    # Expand tilde if present
-    QT_ROOT_ARG="${QT_ROOT_ARG/#\~/$HOME}"
+    # Expand tilde if present at the start
+    case "$QT_ROOT_ARG" in
+        "~"/*) QT_ROOT_ARG="$HOME/${QT_ROOT_ARG#\~/}" ;;
+        "~")   QT_ROOT_ARG="$HOME" ;;
+    esac
     # Convert to absolute path if it exists
     if [ -e "$QT_ROOT_ARG" ]; then
         QT_ROOT_ARG=$(cd "$QT_ROOT_ARG" && pwd)
@@ -51,7 +54,7 @@ if [ -n "$QT_ROOT_ARG" ]; then
 fi
 
 # Validate architecture
-if [[ "$ARCH" != "x86_64" && "$ARCH" != "aarch64" ]]; then
+if [ "$ARCH" != "x86_64" ] && [ "$ARCH" != "aarch64" ]; then
     echo "Error: Architecture must be one of: x86_64, aarch64"
     exit 1
 fi
@@ -66,10 +69,12 @@ CMAKE_FILE="${SOURCE_DIR}CMakeLists.txt"
 GIT_VERSION=$(git describe --tags --always --dirty 2>/dev/null || echo "0.0.0-unknown")
 
 # Extract numeric version components for compatibility
-if [[ $GIT_VERSION =~ ^v?([0-9]+)\.([0-9]+)\.([0-9]+) ]]; then
-    MAJOR="${BASH_REMATCH[1]}"
-    MINOR="${BASH_REMATCH[2]}"
-    PATCH="${BASH_REMATCH[3]}"
+# Match versions like: v1.2.3, 1.2.3, v1.2.3-extra, etc.
+MAJOR=$(echo "$GIT_VERSION" | sed -n 's/^v\{0,1\}\([0-9]\{1,\}\)\.[0-9]\{1,\}\.[0-9]\{1,\}.*/\1/p')
+MINOR=$(echo "$GIT_VERSION" | sed -n 's/^v\{0,1\}[0-9]\{1,\}\.\([0-9]\{1,\}\)\.[0-9]\{1,\}.*/\1/p')
+PATCH=$(echo "$GIT_VERSION" | sed -n 's/^v\{0,1\}[0-9]\{1,\}\.[0-9]\{1,\}\.\([0-9]\{1,\}\).*/\1/p')
+
+if [ -n "$MAJOR" ] && [ -n "$MINOR" ] && [ -n "$PATCH" ]; then
     PROJECT_VERSION="$MAJOR.$MINOR.$PATCH"
 else
     MAJOR="0"
@@ -238,7 +243,7 @@ CMAKE_EXTRA_FLAGS="$CMAKE_EXTRA_FLAGS -DQt6_ROOT=$QT_DIR"
 
 # shellcheck disable=SC2086
 cmake "../$SOURCE_DIR" -DCMAKE_BUILD_TYPE="$BUILD_TYPE" -DCMAKE_INSTALL_PREFIX=/usr $CMAKE_EXTRA_FLAGS
-make -j$(nproc)
+make -j"$(nproc)"
 
 echo "Creating AppDir..."
 # Install to AppDir
@@ -256,13 +261,60 @@ fi
 # Create the AppRun file if not created by the install process
 if [ ! -f "$APPDIR/AppRun" ]; then
     cat > "$APPDIR/AppRun" << 'EOF'
-#!/bin/bash
+#!/bin/sh
 HERE="$(dirname "$(readlink -f "${0}")")"
 export PATH="${HERE}/usr/bin:${PATH}"
 export LD_LIBRARY_PATH="${HERE}/usr/lib:${LD_LIBRARY_PATH}"
 export QT_PLUGIN_PATH="${HERE}/usr/plugins"
 export QML_IMPORT_PATH="${HERE}/usr/qml"
 export QT_QPA_PLATFORM_PLUGIN_PATH="${HERE}/usr/plugins/platforms"
+
+# Handle X11 authorization when running as root (via sudo or pkexec)
+# This fixes "Authorization required, but no authorization protocol specified" errors
+if [ "$(id -u)" = "0" ]; then
+    # Determine original user from sudo or pkexec
+    ORIGINAL_USER=""
+    ORIGINAL_UID=""
+    ORIGINAL_HOME=""
+    
+    if [ -n "$SUDO_USER" ]; then
+        ORIGINAL_USER="$SUDO_USER"
+        ORIGINAL_UID="$SUDO_UID"
+        ORIGINAL_HOME=$(getent passwd "$SUDO_USER" | cut -d: -f6)
+    elif [ -n "$PKEXEC_UID" ]; then
+        ORIGINAL_UID="$PKEXEC_UID"
+        ORIGINAL_USER=$(getent passwd "$PKEXEC_UID" | cut -d: -f1)
+        ORIGINAL_HOME=$(getent passwd "$PKEXEC_UID" | cut -d: -f6)
+    fi
+    
+    if [ -n "$ORIGINAL_USER" ] && [ -n "$ORIGINAL_HOME" ]; then
+        # Try to grant root access to the X display using xhost
+        # This must be run as the original user who owns the display
+        if command -v xhost >/dev/null 2>&1; then
+            if [ -n "$DISPLAY" ]; then
+                # Run xhost as the original user to grant root access
+                su "$ORIGINAL_USER" -c "xhost +local:root" >/dev/null 2>&1 || true
+            fi
+        fi
+        
+        # Set XAUTHORITY to the original user's .Xauthority if not already set
+        if [ -z "$XAUTHORITY" ]; then
+            if [ -f "$ORIGINAL_HOME/.Xauthority" ]; then
+                export XAUTHORITY="$ORIGINAL_HOME/.Xauthority"
+            fi
+        fi
+        
+        # Ensure DISPLAY is set (for pkexec which may not preserve it)
+        if [ -z "$DISPLAY" ]; then
+            # Try common X11 display socket
+            if [ -S "/tmp/.X11-unix/X0" ]; then
+                export DISPLAY=":0"
+            fi
+        fi
+    fi
+fi
+
+# The binary handles privilege elevation internally via pkexec if needed
 exec "${HERE}/usr/bin/rpi-imager" "$@"
 EOF
     chmod +x "$APPDIR/AppRun"
@@ -279,7 +331,9 @@ export QMAKE="$QT_DIR/bin/qmake"
 export LD_LIBRARY_PATH="$QT_DIR/lib:$LD_LIBRARY_PATH"
 # Optimize deployment: exclude translations and unnecessary libraries
 export LINUXDEPLOY_PLUGIN_QT_IGNORE_GLOB="*/translations/*"
-"$LINUXDEPLOY" --appdir="$APPDIR" --plugin=qt --exclude-library="libwayland-*" --verbosity=0
+# Exclude libsystemd - it must come from the host system to work correctly with DBus
+# Including it causes compatibility issues (see https://github.com/raspberrypi/rpi-imager/issues/1304)
+"$LINUXDEPLOY" --appdir="$APPDIR" --plugin=qt --exclude-library="libwayland-*" --exclude-library="libsystemd*" --verbosity=0
 
 # Hook for removing files before AppImage creation
 echo "Pre-packaging hook - opportunity to remove unwanted files"
@@ -325,6 +379,7 @@ echo "Creating AppImage..."
 # Remove old symlinks for this variant only
 rm -f "$PWD/rpi-imager-desktop-$ARCH.AppImage"
 rm -f "$PWD/rpi-imager-$ARCH.AppImage"  # Legacy symlink name
+
 # Ensure LD_LIBRARY_PATH is still set for this call too
 export LD_LIBRARY_PATH="$QT_DIR/lib:$LD_LIBRARY_PATH"
 # Explicitly specify the desktop file to ensure correct naming
@@ -333,36 +388,18 @@ export LD_LIBRARY_PATH="$QT_DIR/lib:$LD_LIBRARY_PATH"
     --output=appimage \
     --verbosity=0
 
-# Rename the output file if needed
-# Find and rename the AppImage created by linuxdeploy to our standardized name
-RENAMED=false
-for appimage in *.AppImage; do
-    # Skip symlinks
-    if [ -L "$appimage" ]; then
-        continue
-    fi
-    # Skip if this is already our target file
-    if [ "$appimage" = "$(basename "$OUTPUT_FILE")" ]; then
-        RENAMED=true
-        break
-    fi
-    # Skip if this is a CLI or embedded variant (has those keywords in the name)
-    if [[ "$appimage" == *"CLI"* ]] || [[ "$appimage" == *"Embedded"* ]]; then
-        continue
-    fi
-    # Rename the generic AppImage created by linuxdeploy to our standardized desktop variant name
-    if [[ "$appimage" =~ ^Raspberry_Pi_Imager(-[0-9.]+)?-${ARCH}\.AppImage$ ]]; then
-        echo "Renaming '$appimage' to '$(basename "$OUTPUT_FILE")'"
-        mv "$appimage" "$OUTPUT_FILE"
-        RENAMED=true
-        break
-    fi
-done
-
-# Check if we successfully found/created the output file
-if [ "$RENAMED" = false ] && [ ! -f "$OUTPUT_FILE" ]; then
-    echo "Warning: Could not find AppImage to rename. Looking for any matching AppImage..."
-    ls -la *.AppImage 2>/dev/null || true
+# Rename the output file from linuxdeploy's default name to our versioned name
+# linuxdeploy creates: Raspberry_Pi_Imager-${ARCH}.AppImage (based on Name= in desktop file)
+LINUXDEPLOY_OUTPUT="Raspberry_Pi_Imager-${ARCH}.AppImage"
+if [ -f "$LINUXDEPLOY_OUTPUT" ]; then
+    echo "Renaming '$LINUXDEPLOY_OUTPUT' to '$(basename "$OUTPUT_FILE")'"
+    mv "$LINUXDEPLOY_OUTPUT" "$OUTPUT_FILE"
+elif [ -f "$OUTPUT_FILE" ]; then
+    echo "Output file already exists: $OUTPUT_FILE"
+else
+    echo "Warning: Expected linuxdeploy output '$LINUXDEPLOY_OUTPUT' not found"
+    echo "Looking for any matching AppImage..."
+    ls -la ./*.AppImage 2>/dev/null || true
 fi
 
 echo "AppImage created at $OUTPUT_FILE"
@@ -384,4 +421,4 @@ fi
 ln -s "$(basename "$OUTPUT_FILE")" "$DESCRIPTIVE_SYMLINK"
 echo "Created symlink: $DESCRIPTIVE_SYMLINK -> $(basename "$OUTPUT_FILE")"
 
-echo "Build completed successfully for $ARCH architecture." 
+echo "Build completed successfully for $ARCH architecture."
