@@ -10,6 +10,12 @@
 /* Repository URL */
 #define OSLIST_URL                        "https://downloads.raspberrypi.com/os_list_imagingutility_v4.json"
 
+/* Custom repository manifest file extension (without leading dot) */
+#define MANIFEST_EXTENSION                "rpi-imager-manifest"
+
+/* MIME type for manifest files */
+#define MANIFEST_MIME_TYPE                "application/vnd.raspberrypi.imager-manifest+json"
+
 /* Time synchronization URL (only used on linuxfb QPA platform, URL must be HTTP) */
 #define TIME_URL                          "http://downloads.raspberrypi.com/"
 
