@@ -107,6 +107,21 @@
         <source>PEM Files (*.pem);;All Files (*)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>PEM Files (*.pem)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Files (*)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AsyncCacheWriter</name>
+    <message>
+        <source>Cache write error: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CommonStrings</name>
@@ -238,6 +253,10 @@
         <source>Localisation configured</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Authorized keys files (authorized_keys)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ConfirmSystemDriveDialog</name>
@@ -452,10 +471,6 @@
         <source>Access denied error while writing file to disk.</source>
         <translation>הגישה נדחתה תוך כדי הצריבה לכונן.</translation>
     </message>
-    <message>
-        <source>Error writing file to disk</source>
-        <translation>שגיאה בצריבת קובץ לכונן</translation>
-    </message>
     <message>
         <source>Error writing to storage (while flushing)</source>
         <translation>שגיאת צריבה לאחסון (במהלך מחיקה מוחלטת)</translation>
@@ -636,6 +651,26 @@
         <source>Failed to write secure boot files: %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Unmounting volumes...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cleaning disk...</source>
+        <translation type="unfinished">הכונן מתנקה…</translation>
+    </message>
+    <message>
+        <source>Cleaning disk (legacy method)...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Writing customization files...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to allocate buffer for MBR zeroing</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DriveFormatThread</name>
@@ -829,6 +864,17 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ImComboBox</name>
+    <message>
+        <source>Type to search: &quot;%1&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>(press again to cycle)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ImFileDialog</name>
     <message>
@@ -859,6 +905,98 @@
         <source>No files in this folder</source>
         <translation>אין קבצים בתיקייה הזאת</translation>
     </message>
+    <message>
+        <source>Folder: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Documents</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Downloads</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Home</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File name:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter filename…</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Navigate to a folder using the panel on the left,
+or type a path in the address bar above.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished">שמירה</translation>
+    </message>
+</context>
+<context>
+    <name>ImOptionButton</name>
+    <message>
+        <source>Opens in browser</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ImOptionPill</name>
+    <message>
+        <source>Opens in browser</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ImPasswordField</name>
+    <message>
+        <source>Password is visible. Press F2 to hide.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password is hidden. Press F2 to show.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password is currently visible. Activate to hide it.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password is currently hidden. Activate to show it.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ImPopup</name>
+    <message>
+        <source>Dialog</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ImSaveFileDialog</name>
+    <message>
+        <source>Save File</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImTextField</name>
@@ -965,6 +1103,14 @@
         <source> or </source>
         <translation> או </translation>
     </message>
+    <message>
+        <source>Save Performance Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>JSON files (*.json);;All files (*)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>KeychainPermissionDialog</name>
@@ -1089,6 +1235,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>NativeFileDialog</name>
+    <message>
+        <source>File type:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>OSListModel</name>
     <message>
@@ -1185,10 +1338,6 @@
         <source>Token received from browser</source>
         <translation>התקבל אסימון מהדפדפן</translation>
     </message>
-    <message>
-        <source>Sign in to receive a token and enable Raspberry Pi Connect.</source>
-        <translation>יש להיכנס כדי לקבל אסימון ולהפעיל את Raspberry Pi Connect.</translation>
-    </message>
     <message>
         <source>Open the Raspberry Pi Connect website in your browser to sign in and receive an authentication token</source>
         <translation type="unfinished"></translation>
@@ -1241,6 +1390,10 @@
         <source>Authentication token:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Sign in to receive a token and enable Raspberry Pi Connect</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -1264,6 +1417,12 @@ Please run as Administrator.</source>
 Please run with elevated privileges: sudo %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>You are not running as root.
+
+Click &quot;Install Authorization&quot; to set up automatic privilege elevation, or run manually with: sudo %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RemoteAccessStep</name>
@@ -1279,10 +1438,6 @@ Please run with elevated privileges: sudo %1</source>
         <source>Use public key authentication</source>
         <translation>להשתמש באימות עם מפתח ציבורי</translation>
     </message>
-    <message>
-        <source>Select SSH Public Key</source>
-        <translation>בחירת מפתח SSH ציבורי</translation>
-    </message>
     <message>
         <source>Customisation: SSH authentication</source>
         <translation>התאמה אישית: אימות SSH</translation>
@@ -1299,18 +1454,6 @@ Please run with elevated privileges: sudo %1</source>
         <source>Authentication mechanism:</source>
         <translation>מנגנון אימות:</translation>
     </message>
-    <message>
-        <source>Enter public key or click BROWSE</source>
-        <translation>נא למלא מפתח ציבורי או ללחוץ על עיון</translation>
-    </message>
-    <message>
-        <source>Failed to read SSH key file</source>
-        <translation>קריאת קובץ מפתח ה־SSH נכשלה</translation>
-    </message>
-    <message>
-        <source>Select an SSH public key file from your computer to enable key-based authentication</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Enable secure shell access for remote command-line control of your Raspberry Pi</source>
         <translation type="unfinished"></translation>
@@ -1335,18 +1478,10 @@ Please run with elevated privileges: sudo %1</source>
         <source>Allow SSH login using a cryptographic key pair instead of a password. More secure than password authentication.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Enter or paste your SSH public key, or use the Browse button to select a public key file (typically id_rsa.pub or id_ed25519.pub).</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Choose how you will authenticate when connecting to your Raspberry Pi via SSH. Password authentication uses the account credentials you configured. Public key authentication uses a cryptographic key pair and is more secure.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Public key:</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>RepositoryDialog</name>
@@ -1445,22 +1580,10 @@ Please run with elevated privileges: sudo %1</source>
         <source>Learn about Secure Boot</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Your boot partition will be signed using the RSA private key configured in App Options.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>This will create boot.img and boot.sig files required for Raspberry Pi Secure Boot.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Private Key: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>(not configured)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Public Key Fingerprint: %1</source>
         <translation type="unfinished"></translation>
@@ -1473,6 +1596,137 @@ Please run with elevated privileges: sudo %1</source>
         <source>(unable to compute)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>RSA Private Key</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select an RSA 2048-bit private key for signing boot images in secure boot mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select RSA Private Key</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PEM Files (*.pem);;All Files (*)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Selected: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your boot partition will be signed using the selected RSA private key.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please select an RSA private key above to enable secure boot signing.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PEM Files (*.pem)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Files (*)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SshKeyManager</name>
+    <message>
+        <source>No SSH keys configured</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 SSH key configured</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 SSH keys configured</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide the list of SSH keys</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show the list of SSH keys</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH keys list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH key %1: %2, %3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH key %1: %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH key %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove SSH key: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove SSH key %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Paste key or click BROWSE to select file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH public key input</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Paste an SSH public key here or use the browse button to select a key file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select SSH Public Key</source>
+        <translation type="unfinished">בחירת מפתח SSH ציבורי</translation>
+    </message>
+    <message>
+        <source>Add the entered SSH key</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select an SSH public key file to add</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StorageSelectionStep</name>
@@ -1845,14 +2099,6 @@ to show system drives.</source>
 </source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Warning: Only replace the token if you initiated this action. </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>If you didn&apos;t, someone could be trying to push a bad token to RPi Imager.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Replace token</source>
         <translation type="unfinished"></translation>
@@ -1877,6 +2123,10 @@ to show system drives.</source>
         <source>Secure Boot</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Warning: Only overwrite the token if you initiated this action.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WizardStepBase</name>
@@ -2019,6 +2269,10 @@ to show system drives.</source>
         <source>Writing in progress — do not disconnect the storage device</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Please wait... %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>main</name>
@@ -2098,5 +2352,25 @@ to show system drives.</source>
         <source>Exit Raspberry Pi Imager - you must restart with elevated privileges to write images</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Install Authorization</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Install system authorization to allow Raspberry Pi Imager to run with elevated privileges</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save Performance Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>JSON files (*.json)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All files (*)</source>
+        <translation type="unfinished">כל הקבצים (*)</translation>
+    </message>
 </context>
 </TS>
