@@ -107,6 +107,21 @@
         <source>PEM Files (*.pem);;All Files (*)</source>
         <translation>File PEM (*.pem);;Tutti i file (*)</translation>
     </message>
+    <message>
+        <source>PEM Files (*.pem)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Files (*)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AsyncCacheWriter</name>
+    <message>
+        <source>Cache write error: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CommonStrings</name>
@@ -238,6 +253,10 @@
         <source>Localisation configured</source>
         <translation>Localizzazione configurata</translation>
     </message>
+    <message>
+        <source>Authorized keys files (authorized_keys)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ConfirmSystemDriveDialog</name>
@@ -452,10 +471,6 @@
         <source>Access denied error while writing file to disk.</source>
         <translation>Errore accesso negato durante la scrittura del file su disco.</translation>
     </message>
-    <message>
-        <source>Error writing file to disk</source>
-        <translation>Errore scrittura file su disco</translation>
-    </message>
     <message>
         <source>Error writing to storage (while flushing)</source>
         <translation>Errore scrittura nello storage (durante flushing)</translation>
@@ -636,6 +651,26 @@
         <source>Failed to write secure boot files: %1</source>
         <translation>Impossibile scrivere i file di Secure Boot: %1</translation>
     </message>
+    <message>
+        <source>Unmounting volumes...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cleaning disk...</source>
+        <translation type="unfinished">Pulizia del disco...</translation>
+    </message>
+    <message>
+        <source>Cleaning disk (legacy method)...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Writing customization files...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to allocate buffer for MBR zeroing</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DriveFormatThread</name>
@@ -829,6 +864,17 @@
         <translation>Questo pulsante sarà abilitato dopo 2 secondi</translation>
     </message>
 </context>
+<context>
+    <name>ImComboBox</name>
+    <message>
+        <source>Type to search: &quot;%1&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>(press again to cycle)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ImFileDialog</name>
     <message>
@@ -859,6 +905,98 @@
         <source>No files in this folder</source>
         <translation>Nessun file in questa cartella</translation>
     </message>
+    <message>
+        <source>Folder: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Documents</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Downloads</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Home</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File name:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter filename…</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Navigate to a folder using the panel on the left,
+or type a path in the address bar above.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished">Salva</translation>
+    </message>
+</context>
+<context>
+    <name>ImOptionButton</name>
+    <message>
+        <source>Opens in browser</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ImOptionPill</name>
+    <message>
+        <source>Opens in browser</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ImPasswordField</name>
+    <message>
+        <source>Password is visible. Press F2 to hide.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password is hidden. Press F2 to show.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password is currently visible. Activate to hide it.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password is currently hidden. Activate to show it.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ImPopup</name>
+    <message>
+        <source>Dialog</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ImSaveFileDialog</name>
+    <message>
+        <source>Save File</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImTextField</name>
@@ -965,6 +1103,14 @@
         <source> or </source>
         <translation> o </translation>
     </message>
+    <message>
+        <source>Save Performance Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>JSON files (*.json);;All files (*)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>KeychainPermissionDialog</name>
@@ -1086,7 +1232,14 @@
     <name>MacFile</name>
     <message>
         <source>Raspberry Pi Imager needs to access the disk to write the image.</source>
-        <translation>Raspberry Pi Imager deve accedere al disco per scrivere l&apos;immagine.</translation>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>NativeFileDialog</name>
+    <message>
+        <source>File type:</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1185,10 +1338,6 @@
         <source>Token received from browser</source>
         <translation>Token ricevuto dal browser</translation>
     </message>
-    <message>
-        <source>Sign in to receive a token and enable Raspberry Pi Connect.</source>
-        <translation>Accedi per ricevere un token e abilitare Raspberry Pi Connect.</translation>
-    </message>
     <message>
         <source>Open the Raspberry Pi Connect website in your browser to sign in and receive an authentication token</source>
         <translation>Apri il sito di Raspberry Pi Connect nel browser per accedere e ricevere un token di autenticazione</translation>
@@ -1241,6 +1390,10 @@
         <source>Authentication token:</source>
         <translation>Token di autenticazione:</translation>
     </message>
+    <message>
+        <source>Sign in to receive a token and enable Raspberry Pi Connect</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -1268,6 +1421,12 @@ Please run with elevated privileges: sudo %1</source>
 
 Esegui con privilegi elevati: sudo %1</translation>
     </message>
+    <message>
+        <source>You are not running as root.
+
+Click &quot;Install Authorization&quot; to set up automatic privilege elevation, or run manually with: sudo %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RemoteAccessStep</name>
@@ -1283,10 +1442,6 @@ Esegui con privilegi elevati: sudo %1</translation>
         <source>Use public key authentication</source>
         <translation>Usa autenticazione con chiave pubblica</translation>
     </message>
-    <message>
-        <source>Select SSH Public Key</source>
-        <translation>Seleziona chiave pubblica SSH</translation>
-    </message>
     <message>
         <source>Customisation: SSH authentication</source>
         <translation>Personalizzazione: Autenticazione SSH</translation>
@@ -1303,18 +1458,6 @@ Esegui con privilegi elevati: sudo %1</translation>
         <source>Authentication mechanism:</source>
         <translation>Meccanismo di autenticazione:</translation>
     </message>
-    <message>
-        <source>Enter public key or click BROWSE</source>
-        <translation>Inserisci la chiave pubblica o clicca Sfoglia</translation>
-    </message>
-    <message>
-        <source>Failed to read SSH key file</source>
-        <translation>Impossibile leggere il file della chiave SSH</translation>
-    </message>
-    <message>
-        <source>Select an SSH public key file from your computer to enable key-based authentication</source>
-        <translation>Seleziona un file di chiave pubblica SSH dal computer per abilitare l&apos;autenticazione a chiave</translation>
-    </message>
     <message>
         <source>Enable secure shell access for remote command-line control of your Raspberry Pi</source>
         <translation>Abilita l&apos;accesso shell sicuro per il controllo remoto a riga di comando del tuo Raspberry Pi</translation>
@@ -1339,18 +1482,10 @@ Esegui con privilegi elevati: sudo %1</translation>
         <source>Allow SSH login using a cryptographic key pair instead of a password. More secure than password authentication.</source>
         <translation>Consenti login SSH usando una coppia di chiavi crittografica invece della password. Più sicuro della password.</translation>
     </message>
-    <message>
-        <source>Enter or paste your SSH public key, or use the Browse button to select a public key file (typically id_rsa.pub or id_ed25519.pub).</source>
-        <translation>Inserisci o incolla la tua chiave pubblica SSH, oppure usa il pulsante Sfoglia per selezionare un file (tipicamente id_rsa.pub o id_ed25519.pub).</translation>
-    </message>
     <message>
         <source>Choose how you will authenticate when connecting to your Raspberry Pi via SSH. Password authentication uses the account credentials you configured. Public key authentication uses a cryptographic key pair and is more secure.</source>
         <translation>Scegli come autenticarti quando ti connetti via SSH al tuo Raspberry Pi. L&apos;autenticazione con password usa le credenziali dell&apos;account configurate. Quella con chiave pubblica usa una coppia di chiavi crittografica ed è più sicura.</translation>
     </message>
-    <message>
-        <source>Public key:</source>
-        <translation>Chiave pubblica:</translation>
-    </message>
 </context>
 <context>
     <name>RepositoryDialog</name>
@@ -1449,22 +1584,10 @@ Esegui con privilegi elevati: sudo %1</translation>
         <source>Learn about Secure Boot</source>
         <translation>Scopri di più su Secure Boot</translation>
     </message>
-    <message>
-        <source>Your boot partition will be signed using the RSA private key configured in App Options.</source>
-        <translation>La partizione di boot verrà firmata usando la chiave privata RSA configurata nelle Opzioni App.</translation>
-    </message>
     <message>
         <source>This will create boot.img and boot.sig files required for Raspberry Pi Secure Boot.</source>
         <translation>Questo creerà i file boot.img e boot.sig richiesti per Secure Boot di Raspberry Pi.</translation>
     </message>
-    <message>
-        <source>Private Key: %1</source>
-        <translation>Chiave privata: %1</translation>
-    </message>
-    <message>
-        <source>(not configured)</source>
-        <translation>(non configurata)</translation>
-    </message>
     <message>
         <source>Public Key Fingerprint: %1</source>
         <translation>Fingerprint chiave pubblica: %1</translation>
@@ -1477,6 +1600,137 @@ Esegui con privilegi elevati: sudo %1</translation>
         <source>(unable to compute)</source>
         <translation>(impossibile calcolare)</translation>
     </message>
+    <message>
+        <source>RSA Private Key</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change</source>
+        <translation type="unfinished">Cambia</translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation type="unfinished">Seleziona</translation>
+    </message>
+    <message>
+        <source>Select an RSA 2048-bit private key for signing boot images in secure boot mode</source>
+        <translation type="unfinished">Seleziona una chiave privata RSA 2048-bit per firmare le immagini di avvio in modalità Secure Boot</translation>
+    </message>
+    <message>
+        <source>Select RSA Private Key</source>
+        <translation type="unfinished">Seleziona chiave privata RSA</translation>
+    </message>
+    <message>
+        <source>PEM Files (*.pem);;All Files (*)</source>
+        <translation type="unfinished">File PEM (*.pem);;Tutti i file (*)</translation>
+    </message>
+    <message>
+        <source>Selected: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your boot partition will be signed using the selected RSA private key.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please select an RSA private key above to enable secure boot signing.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PEM Files (*.pem)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Files (*)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SshKeyManager</name>
+    <message>
+        <source>No SSH keys configured</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 SSH key configured</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 SSH keys configured</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide the list of SSH keys</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show the list of SSH keys</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH keys list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH key %1: %2, %3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH key %1: %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH key %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove SSH key: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove SSH key %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Paste key or click BROWSE to select file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SSH public key input</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Paste an SSH public key here or use the browse button to select a key file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select SSH Public Key</source>
+        <translation type="unfinished">Seleziona chiave pubblica SSH</translation>
+    </message>
+    <message>
+        <source>Add the entered SSH key</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select an SSH public key file to add</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StorageSelectionStep</name>
@@ -1541,38 +1795,26 @@ to show system drives.</source>
         <translation>Tutti i dispositivi sono nascosti dal filtro.
 Deseleziona &apos;Escludi le unità di sistema&apos;
 per visualizzare le unità di sistema.</translation>
-    </message>
-    <message>
-        <source>When checked, system drives are hidden from the list. Uncheck to show all drives
-including system drives.</source>
-        <translation>Se attivato, le unità di sistema vengono nascoste dall’elenco. Disattiva
-per mostrare tutte le unità, incluse quelle di sistema.</translation>
     </message>
     <message>
         <source>No storage devices found. Please connect a storage device to continue.</source>
         <translation>Nessun dispositivo di archiviazione trovato. Collega un dispositivo per continuare.</translation>
     </message>
     <message>
-        <source>No valid storage devices are currently available. All visible devices are
-read-only. Try connecting a new storage device, or uncheck &apos;Exclude system drives&apos;
-to show hidden system drives.</source>
-        <translation>Nessun dispositivo di archiviazione valido è attualmente disponibile. Tutti
-i dispositivi visibili sono in sola lettura. Prova a collegare un nuovo dispositivo
-o deseleziona &apos;Escludi le unità di sistema&apos; per mostrare quelle nascoste.</translation>
+        <source>When checked, system drives are hidden from the list. Uncheck to show all drives including system drives.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>No valid storage devices are currently available. All devices are read-only.
-Please connect a writable storage device to continue.</source>
-        <translation>Nessun dispositivo di archiviazione valido è attualmente disponibile. Tutti
-i dispositivi sono in sola lettura. Collega un dispositivo scrivibile per
-continuare.</translation>
+        <source>No valid storage devices are currently available. All visible devices are read-only. Try connecting a new storage device, or uncheck &apos;Exclude system drives&apos; to show hidden system drives.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>No valid storage devices are currently available. Uncheck &apos;Exclude system
-drives&apos; to show hidden system drives, or connect a new storage device.</source>
-        <translation>Nessun dispositivo di archiviazione valido è attualmente disponibile.
-Deseleziona &apos;Escludi le unità di sistema&apos; per mostrare quelle nascoste o collega un
-nuovo dispositivo.</translation>
+        <source>No valid storage devices are currently available. All devices are read-only. Please connect a writable storage device to continue.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No valid storage devices are currently available. Uncheck &apos;Exclude system drives&apos; to show hidden system drives, or connect a new storage device.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1870,14 +2112,6 @@ nuovo dispositivo.</translation>
 
 </translation>
     </message>
-    <message>
-        <source>Warning: Only replace the token if you initiated this action. </source>
-        <translation>Attenzione: Sostituisci il token solo se hai avviato tu questa azione. </translation>
-    </message>
-    <message>
-        <source>If you didn&apos;t, someone could be trying to push a bad token to RPi Imager.</source>
-        <translation>Se non sei stato tu, qualcuno potrebbe star cercando di inviare un token malevolo a RPi Imager.</translation>
-    </message>
     <message>
         <source>Replace token</source>
         <translation>Sostituisci token</translation>
@@ -1902,6 +2136,10 @@ nuovo dispositivo.</translation>
         <source>Secure Boot</source>
         <translation>Secure Boot</translation>
     </message>
+    <message>
+        <source>Warning: Only overwrite the token if you initiated this action.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WizardStepBase</name>
@@ -2044,6 +2282,10 @@ nuovo dispositivo.</translation>
         <source>Writing in progress — do not disconnect the storage device</source>
         <translation>Scrittura in corso — non scollegare il dispositivo di archiviazione</translation>
     </message>
+    <message>
+        <source>Please wait... %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>main</name>
@@ -2123,5 +2365,25 @@ nuovo dispositivo.</translation>
         <source>Exit Raspberry Pi Imager - you must restart with elevated privileges to write images</source>
         <translation>Esci da Raspberry Pi Imager - devi riavviare con privilegi elevati per scrivere immagini</translation>
     </message>
+    <message>
+        <source>Install Authorization</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Install system authorization to allow Raspberry Pi Imager to run with elevated privileges</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save Performance Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>JSON files (*.json)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All files (*)</source>
+        <translation type="unfinished">Tutti i file (*)</translation>
+    </message>
 </context>
 </TS>
